/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1	
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Firefox Dock Tile Plugin
 *
 * The Initial Developer of the Original Code is
 * Thomas K. Dyas <tom.dyas@gmail.com>.
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#import "FirefoxDockTilePlugin.h"


@implementation FirefoxDockTilePlugin

- (id) init
{
	if ((self = [super init]) != nil) {
		mDockTile = nil;
		mDockMenu = nil;
	}
	return self;
}

- (void) dealloc
{
	[self setDockTile:nil];
	[super dealloc];
}

- (void) setDockTile:(NSDockTile *)dockTile
{
	if (mDockTile == dockTile)
		return;
	
	[mDockTile release];
	mDockTile = [dockTile retain];
	
	if (mDockTile != nil) {
		mDockMenu = [[NSMenu alloc] initWithTitle:@"DockMenu"];
		
		NSMenuItem * item = [[NSMenuItem alloc] initWithTitle:@"Open in Safe Mode"
													   action:@selector(openFirefoxInSafeMode:)
												keyEquivalent:@""];
		[item setTarget:self];
		[mDockMenu addItem:item];
		[item release];
	} else {
		[mDockMenu release];
		mDockMenu = nil;
	}
}

- (NSMenu *) dockMenu
{
	return [[mDockMenu retain] autorelease];
}

- (void) openFirefoxInSafeMode:(id)sender
{
	NSBundle * bundle = [NSBundle bundleForClass:[self class]];
	if (!bundle) {
		NSLog(@"FirefoxDockPlugin: Unable to locate plugin bundle", bundle);
		return;
	}

	NSString * firefoxPath = [bundle bundlePath];
	firefoxPath = [firefoxPath stringByDeletingLastPathComponent];  // remove bundle directory's name
	firefoxPath = [firefoxPath stringByDeletingLastPathComponent];  // remove "PlugIns"
	firefoxPath = [firefoxPath stringByDeletingLastPathComponent];  // remove "Contents"
	if (!firefoxPath) {
		NSLog(@"FirefoxDockPlugin: Unable to determine path to Firefox: bundlePath was '%@'", [bundle bundlePath]);
		return;
	}
	
	NSURL * firefoxURL = [NSURL fileURLWithPath:firefoxPath];
	if (!firefoxURL) {
		NSLog(@"FirefoxDockPlugin: Unable to create URL based on path to Firefox");
		return;
	}
	
	NSMutableDictionary * config = [[[NSMutableDictionary alloc] init] autorelease];
	[config setObject:[NSArray arrayWithObject:@"-safe-mode"] forKey:NSWorkspaceLaunchConfigurationArguments];
	
	NSError * error = nil;
	[[NSWorkspace sharedWorkspace] launchApplicationAtURL:firefoxURL
												  options:NSWorkspaceLaunchDefault
											configuration:config
													error:&error];
	if (error != nil) {
		NSLog(@"FirefoxDockPlugin: Error while launching Firefox: %@", error);
	}
}

@end
